=============
Prapi Summary
=============

|travis_badge|

.. |travis_badge| image:: https://travis-ci.org/nanoporetech/tombo.svg?branch=master
    :target: https://travis-ci.org/nanoporetech/tombo

PRAPI is a one-stop solution for Iso-Seq analysis of analyze alternative transcription initiation (ATI), alternative splicing (AS), alternative cleavage and polyadenylation (APA), natural antisense transcripts (NAT), and circular RNAs (circRNAs) comprehensively. 



============
Installation
============

|pypi_badge|

.. |pypi_badge| image:: https://badge.fury.io/py/ont-tombo.svg
    :target: https://pypi.org/project/ont-tombo/

Basic tombo installation (python 2.7 and 3.4+ support)

::

    # or install pip package (numpy install required before tombo for cython optimization)
    pip install numpy
    pip install prapi

===========
Quick Start
===========

Please make sure docker is installed.If you want to take DE_APA analysis,please make sure that the bam file is generated by PAS_Seq reads.If you want to take Circle analysis,please make sure that the bam file is generated by RNase R easeing reads . Before running the script, you will need to run gmap_build to make a genome reference index. Please make sure that the section info you want is right.
::

$ path=`pwd`
$sudo docker run -it --rm -v ${path}:/data prapi:v1 Pacbio_v16.py -c /data/conf.txt
All parameter is stored in conf.txt.
basic arguments
Output_dir          Name of the output directory
Pacbio_reads       PacBio sequence's full path and name
GMAP_IndexesDir     Directory of genomic index files buided by gmap_build program
GMAP_Process        Number of worker threads for GMAP
Genome_Annotion     Reference annotation  in gpd format
MaxIntron           Max length for one internal intron (default 200000)
Multile_processing  Using parallel version
other arguments
MinDist             Minimum distance between any two poly(A) or transcripts start sites
MinSupport          Minimum number of trusted reads supporting a poly(A) or transcripts
start sites
Width_of_peaks      Peak widths for searching poly(A)
Graph arguments
Group              Groups of different library type to specify ylim for each facet separately
anchorLength        Min anchor Length for Tophat/Bowtie aligner
DElib               The libraries used for differential analysis
P value        (default 0.01)
FDR               (default 0.01)



::


..

   See more complete tutorials on the `documentation page <http://www.bioinfor.org/tool/PRAPI/manual.php>`_.

===
RNA
===


=====================
Further Documentation
=====================


========
Citation
========

Gao Y, Wang H, Zhang H, Wang Y, Chen J, Gu L, (2017), PRAPI: post-transcriptional regulation analysis pipeline for Iso-Seq.Bioinformatics,Bioinformatics, btx830,https://doi.org/10.1093/bioinformatics/btx830 
============
Known Issues
============

-  The bam file provided must be sorted and indexed.

